TODO: TODO_73_23_85_93: use helper to select container ipos:

Make a common helper to select correct container (via `interp_ctx.curr_interp.base_container_ipos`) in all cases:
  *   when `func_envelope` is the first (index 0)
  *   when `func_envelope` is actually prefixed by some `SpecialFunc` like `SpecialFunc.func_id_help_hint`...
